// Copyright (C) 2018-2019 Michel Sabourin 
//
// Sous licence du site SimTurb à : 
// https://michelsabourin.scenari-community.org/SimTurb/co/1siteWeb_1.html
//
// Date : 2018-08-02
//
//Programme d'interpolation sur une colline pour un point
// La colline est constituée d'une liste de points eparpillés dans l'espace sans régularité
// Elle est consituée de 4 colonnes qui comprennent ned, Ouv, Q11, Eta rendement
//On doit déterminer si on désire travailler dans le plan ned-gamma ou ned-qed
// L'interpolation se fait à l'aide des fonctions cshep2d et eval_cshep2d
//
//Version 2
// Date : 2019-03-17
// Scilab 6.0.2
// Date : 2020-04-26
// Scilab 6.1.0
clc;//on efface la console
//Identification du programme sur la console
Version="Version 20200426";
mprintf("\n\n\n*******************************************************************\n");
mprintf("*                          SimTurb                                *\n");
mprintf("*  Bienvenue sur le logiciel de calcul de points sur une colline  *\n");
mprintf("*                      %s                           *",Version);
mprintf("\n*******************************************************************\n");
mprintf("\nDéveloppé sous Scilab 6.1.0 \n\nCopyright Michel Sabourin 2018-2020 \n");
mprintf("Détails sur la license à:\n  https://michelsabourin.scenari-community.org/SimTurb/co/1siteWeb_1.html \n")
mprintf("\n\nInstructions :\n -Il faut indiquer le fichier .xls contenant les données de la colline. \n ");
mprintf("-Pour quitter faire quit dans cette console. \n\n\n");

//Lecture du fichier EXCEl *.xls qui contient la colline dans le premier onglet

[FileName, PathName, FilterIndex]=uigetfile("*.xls", "%USERPROFILE%", "Fichier colline?");
if FilterIndex==0 then;
    abort;
end;
Fichier=fullfile(PathName,FileName);
Feuilles=readxls(Fichier);
Colline=Feuilles(1).value;
Option=0;

// On confirme avec l'usager l'ordonnée en débit ou en ouverture 
Params=x_mdialog('Voulez-vous l''ordonnée en débit (0) ou en ouverture (1)',["cY="],[string(Option)]);
if size(Params,"*")==0 then;
    abort;
end;
Option=evstr(Params);
if Option==0 then
    cX=1;//ned
    cY=3;//Qed
    cZ1=4;//eta rendement
    cZ2=2;//gamma ouverture
else
    cX=1;//ned
    cY=2;//gamma
    cZ1=4;//eta
    cZ2=3;//Qed    
end    
// Calcule des coefficients d'interpolation pour les deux Z choisis.  
// Paramètre de la normalisation de la colline
    [etamax,ligneDuMax]=max(Colline(:,4));
//Pour le calcul sur la colline normalisée, les données sont divisées par leur valeur à la ligne du maximum de rendement
    Z1coef=cshep2d([Colline(:, cX)/Colline(ligneDuMax, cX) Colline(:,cY)/Colline(ligneDuMax, cY) Colline(:,cZ1)/Colline(ligneDuMax, cZ1)]);
    Z2coef=cshep2d([Colline(:, cX)/Colline(ligneDuMax, cX) Colline(:,cY)/Colline(ligneDuMax, cY) Colline(:,cZ2)/Colline(ligneDuMax, cZ2)]);
  
X=0;Y=0;rep='oui';


while rep=='oui';
//On demande à l'usager les valeurs X et Y où il veut connaître le Z1 et le Z2
    if Option==0 then
        Params=x_mdialog('Valeurs des coordonnées dans le plan',["ned=";"Qed="],[string(X);string(Y)] );

    else
        Params=x_mdialog('Valeurs des coordonnées dans le plan',["ned=";"Ouv="],[string(X);string(Y)] );
    end 
    if size(Params,"*")==0 then;
        abort;
    end;
    Paramd=evstr(Params);        
    X=Paramd(1);
    Y=Paramd(2);
    
//On interpolle pour chaque colonne Z
//Pour le calcul sur la colline normalisée, les données sont divisées par leur valeur à la ligne du maximum de rendement
            Z1=Colline(ligneDuMax, cZ1)*eval_cshep2d(X/Colline(ligneDuMax, cX), Y/Colline(ligneDuMax, cY), Z1coef);
            Z2=Colline(ligneDuMax, cZ2)*eval_cshep2d(X/Colline(ligneDuMax, cX), Y/Colline(ligneDuMax, cY), Z2coef);
//    Z1=eval_cshep2d(X, Y, Z1coef);
//    Z2=eval_cshep2d(X, Y, Z2coef);
    
//On présente le résultat et on interroge pour continuer
    if Option==0 then    
        Params=x_mdialog('Résultats de l''interpolation',["eta=";"Ouv="; "Un autre calcul?"],[string(Z1);string(Z2); rep] )
    else
        Params=x_mdialog('Résultats de l''interpolation',["eta=";"Qed="; "Un autre calcul?"],[string(Z1);string(Z2); rep] )
    end
    if size(Params,"*")==0 then;
        abort;
    end;
    rep=Params(3);
end
